@@ -5,8 +5,8 @@
 
 id2name <- function(txdb, feature.type=c("tx", "exon", "cds"))
 {
-    if(!is(txdb,"TranscriptDb"))
-        stop("'txdb' must be a TranscriptDb object")
+    if (!is(txdb, "TxDb"))
+        stop("'txdb' must be a TxDb object")
     feature.type <- match.arg(feature.type)
     tablename <- switch(feature.type, tx="transcript", exon="exon", cds="cds")
     what_cols <- paste0(c("_", ""), feature.type, c("_id", "_name"))
