@@ -73,7 +73,8 @@
     COLMAP=list(
         exon=c("exon_id", makeFeatureColnames("exon")),
         splicing=c("tx_id", "_tx_id", "exon_rank", "cds_id", "_cds_id"),
-        transcript=c("tx_name", "tx_chrom", "tx_strand", "tx_start", "tx_end"),
+        transcript=c("tx_name", "tx_chrom", "tx_strand", "tx_start", "tx_end",
+          "tx_type"),
         gene="gene_id",
         cds=c("cds_name", "cds_chrom", "cds_strand", "cds_start", "cds_end")
     ),
@@ -110,7 +111,8 @@
     COLMAP=list(
         cds=c("cds_id", makeFeatureColnames("cds")),
         splicing=c("tx_id", "_tx_id", "exon_rank", "exon_id", "_exon_id"),
-        transcript=c("tx_name", "tx_chrom", "tx_strand", "tx_start", "tx_end"),
+        transcript=c("tx_name", "tx_chrom", "tx_strand", "tx_start", "tx_end",
+          "tx_type"),
         gene="gene_id",
         exon=c("exon_name", "exon_chrom", "exon_strand",
                "exon_start", "exon_end")
@@ -153,6 +155,9 @@ translateCols <- function(columns, txdb){
     oriLen <- length(columns) ## not always the same as length(oriCols)
     ## get the available abbreviations as a translation vector (exp)
     names <- .makeColAbbreviations(txdb)
+    if(("TXTYPE" %in% columns) && !.dbSchemaHasTxType(txdb)){
+        names <- c(names, c(tx_type='TXTYPE'))
+    }
     exp <- sub("^_","", names(names))
     names(exp) <- names
 
@@ -215,7 +220,7 @@ translateCols <- function(columns, txdb){
     ans
 }
 
-### In the case of TranscriptDb objects, the distance between 'root_table'
+### In the case of TxDb objects, the distance between 'root_table'
 ### and 'child_table' is always <= 2.
 ### TODO: Revisit this. Not sure it would be guaranteed to work correctly if
 ### the distance between 'root_table' and 'child_table' was >= 3.
@@ -258,11 +263,46 @@ translateCols <- function(columns, txdb){
     paste("WHERE", paste(unlist(sql), collapse = " AND "))
 }
 
+
+.dbSchemaHasTxType <- function(txdb){
+    txFields <- dbListFields(dbconn(txdb),"transcript")
+    "tx_type" %in% txFields
+}
+
+.getSQL_OrderBy <- function(root_table, txdb, what_cols){
+    if( ("transcript.tx_type" %in% what_cols) && !.dbSchemaHasTxType(txdb) ){
+        ## Only THEN do we adjust the result
+        ## Then drop that string
+        what_cols <- what_cols[!(what_cols %in% "transcript.tx_type")]
+        what <- paste(what_cols, collapse=", ")
+    }else{
+        what <- paste(what_cols, collapse=", ")
+    }
+    what
+}
+
+.getSQL_What <- function(root_table, txdb, what_cols){
+    if( ("transcript.tx_type" %in% what_cols) && !.dbSchemaHasTxType(txdb) ){
+        ## Only THEN do we adjust the result
+        what <- what_cols    
+        old <- "transcript.tx_type"  ###paste0(root_table,'.tx_type')
+        new <- "NULL AS tx_type"
+        ## then replace old with new
+        what[what %in% old] <- new
+        what <- paste(what, collapse=", ")
+    }else{
+        what <- paste(what_cols, collapse=", ")
+    }
+    what
+}
+
 .extractData <- function(root_table, txdb, what_cols, child_tables, vals,
                          orderby_cols=NULL)
 {
-    SQL_what <- paste(.asQualifiedColnames(root_table, what_cols),
-                      collapse=", ")
+    ## SQL_what <- paste(.asQualifiedColnames(root_table, what_cols),
+    ##                   collapse=", ")
+    what <- .asQualifiedColnames(root_table, what_cols)
+    SQL_what <- .getSQL_What(root_table, txdb, what)
     SQL_from <- .joinRootToChildTables(root_table, child_tables)
     SQL_where <- .sqlWhereIn(vals)
     if (length(orderby_cols) == 0L)
@@ -316,17 +356,20 @@ translateCols <- function(columns, txdb){
 {
     ans_names <- c(primary_key, child_columns)
     primary_key <- paste0("_", primary_key)
-    what_cols <- c(primary_key,
+    what <- c(primary_key,
                    .asQualifiedColnames(root_table, child_columns))
-    SQL_what <- paste(what_cols, collapse=", ")
+    
+##    SQL_what <- paste(what, collapse=", ")
+    SQL_what <- .getSQL_What(root_table, txdb, what)
     SQL_from <- .joinPrimaryKeyToChildTable(root_table, child_table)
     vals <- list(ids)
     names(vals) <- primary_key
     SQL_where <- .sqlWhereIn(vals)
-    SQL_orderby <- SQL_what
+    ## SQL_orderby <- SQL_what ## similar fix here to the SQL_what
+    SQL_orderby <- .getSQL_OrderBy(root_table, txdb, what)
     SQL <- paste("SELECT DISTINCT", SQL_what, "FROM", SQL_from,
                  SQL_where, "ORDER BY", SQL_orderby)
-    ans <- dbEasyQuery(AnnotationDbi:::dbConn(txdb), SQL)
+    ans <- dbEasyQuery(AnnotationDbi:::dbconn(txdb), SQL)
     names(ans) <- ans_names
     ans
 }
@@ -364,7 +407,7 @@ translateCols <- function(columns, txdb){
     ans
 }
 
-## make a named list from the metadata data.frame
+## me a named list from the metadata data.frame
 .makeMetadataList <- function(meta){
     lst <- as.list(meta[,2])
     names(lst) <- meta[,1]
@@ -392,7 +435,7 @@ translateCols <- function(columns, txdb){
     columns <- translateCols(columns, txdb)
     ## Then proceed with checking
     CORECOLS <- .DBDESC[[root_table]]$CORECOLS
-    assigned_columns <- .assignColToClosestTable(root_table, columns)
+    assigned_columns <- .assignColToClosestTable(root_table, columns) 
     root_columns <- assigned_columns[[root_table]]
     ## Extract the data from the db.
     root_data <- .extractRootData(root_table, txdb, vals, root_columns)
@@ -459,15 +502,9 @@ translateCols <- function(columns, txdb){
 
 setGeneric("transcripts", function(x, ...) standardGeneric("transcripts"))
 
-setMethod("transcripts", "data.frame",
-    function(x, vals=NULL, columns=c("tx_id", "tx_name"))
-        stop("Please use 'transcripts_deprecated' for older ",
-             "data.frame-based transcript metadata.")
-)
-
 ## TODOS: change defaults (WILL break many examples!)
 ## TODO: change defaults from c("tx_id", "tx_name") to: c("TXID", "TXNAME") 
-setMethod("transcripts", "TranscriptDb",
+setMethod("transcripts", "TxDb",
     function(x, vals=NULL, columns=c("tx_id", "tx_name")){
         vals = c(vals, .makeActiveSeqsList("tx_chrom", x))
         .extractFeatureRowsAsGRanges("transcript", x, vals, columns)
@@ -476,14 +513,8 @@ setMethod("transcripts", "TranscriptDb",
 
 setGeneric("exons", function(x, ...) standardGeneric("exons"))
 
-setMethod("exons", "data.frame",
-    function(x, vals=NULL, columns="exon_id")
-        stop("Please use 'exons_deprecated' for older ",
-             "data.frame-based transcript metadata.")
-)
-
 ## TODO: change defaults from c("exon_id") to: c("EXONID") 
-setMethod("exons", "TranscriptDb",
+setMethod("exons", "TxDb",
     function(x, vals=NULL, columns="exon_id"){
         vals = c(vals, .makeActiveSeqsList("exon_chrom", x))
         .extractFeatureRowsAsGRanges("exon", x, vals, columns)
@@ -493,7 +524,7 @@ setMethod("exons", "TranscriptDb",
 setGeneric("cds", function(x, ...) standardGeneric("cds"))
 
 ## TODO: change defaults from c("cds_id") to: c("CDSID") 
-setMethod("cds", "TranscriptDb",
+setMethod("cds", "TxDb",
     function(x, vals=NULL, columns="cds_id"){
         vals = c(vals, .makeActiveSeqsList("cds_chrom", x))
         .extractFeatureRowsAsGRanges("cds", x, vals, columns)
@@ -529,8 +560,8 @@ setGeneric("genes", function(x, ...) standardGeneric("genes"))
 ### different chromosomes are dropped. In that case, the genes are returned
 ### in a GRanges object. Otherwise, they're returned in a GRangesList object
 ### with the metadata columns requested thru 'columns' set at the top level.
-.TranscriptDb.genes <- function(x, vals=NULL, columns="gene_id",
-                                single.strand.genes.only=TRUE)
+.TxDb.genes <- function(x, vals=NULL, columns="gene_id",
+                        single.strand.genes.only=TRUE)
 {
     if (!is.character(columns))
         stop("'columns' must be a character vector")
@@ -545,7 +576,7 @@ setGeneric("genes", function(x, ...) standardGeneric("genes"))
     ## when the same transcript is linked to more than 1 gene (because this
     ## may happen one day and is the reason behind the choice to represent
     ## the 'gene_id' as a CharacterList object instead of a character vector).
-    gene_id <- mcols(tx)$gene_id
+    gene_id <- mcols(tx)[ , "gene_id"]
     ngene_per_tx <- elementLengths(gene_id)
     tx <- tx[rep.int(seq_along(ngene_per_tx), ngene_per_tx)]
     mcols(tx)$gene_id <- unlist(gene_id, use.names=FALSE)
@@ -557,7 +588,14 @@ setGeneric("genes", function(x, ...) standardGeneric("genes"))
     inner_mcols <- mcols(tx_by_gene@unlistData)[columns]
     mcols(tx_by_gene@unlistData) <- NULL
     new_breakpoints <- end(PartitioningByEnd(tx_by_gene))
-    mcols(tx_by_gene) <- .regroup_rows(inner_mcols, new_breakpoints)
+    outter_mcols <- .regroup_rows(inner_mcols, new_breakpoints)
+    gene_id <- outter_mcols$gene_id
+    if (!is.null(gene_id)) {
+        stopifnot(identical(names(tx_by_gene), as.character(gene_id)))
+        outter_mcols$gene_id <- names(tx_by_gene)
+    }
+    mcols(tx_by_gene) <- outter_mcols
+
     ## Compute the gene ranges.
     genes <- range(tx_by_gene)
 
@@ -572,7 +610,7 @@ setGeneric("genes", function(x, ...) standardGeneric("genes"))
     ans
 }
 
-setMethod("genes", "TranscriptDb", .TranscriptDb.genes)
+setMethod("genes", "TxDb", .TxDb.genes)
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -581,7 +619,7 @@ setMethod("genes", "TranscriptDb", .TranscriptDb.genes)
 ### generic is in IRanges
 ###
 
-setMethod("promoters", "TranscriptDb",
+setMethod("promoters", "TxDb",
     function(x, upstream=2000, downstream=200, ...)
     {
         gr <- transcripts(x, ...)
@@ -599,7 +637,7 @@ setGeneric("disjointExons",
              standardGeneric("disjointExons")
 )
 
-setMethod("disjointExons", "TranscriptDb", 
+setMethod("disjointExons", "TxDb", 
     function(x, aggregateGenes=FALSE, includeTranscripts=TRUE, ...) 
     {
         exonsByGene <- exonsBy(x, by="gene")
@@ -662,7 +700,7 @@ setMethod("disjointExons", "TranscriptDb",
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Extractors for features in other databases.
 ###
-### This is for extractors that do NOT point to the TranscriptDb proper.
+### This is for extractors that do NOT point to the TxDb proper.
 ### Such extractors can point to other databases (mirbase.db) OR they can
 ### point to other FeatureDbs within the same package.
 
@@ -692,7 +730,7 @@ setMethod("disjointExons", "TranscriptDb",
 ## main function
 .microRNAs <- function(txdb){
   ## get the data about whether or not we have any info.
-  con <- AnnotationDbi:::dbConn(txdb)
+  con <- AnnotationDbi:::dbconn(txdb)
   bld <- dbGetQuery(con,
            "SELECT value FROM metadata WHERE name='miRBase build ID'")
   src <- DBI::dbGetQuery(con,
@@ -700,7 +738,7 @@ setMethod("disjointExons", "TranscriptDb",
 
   ## And if not - bail out with message
   if(is.na(bld) || dim(bld)[1]==0){
-    stop("this TranscriptDb does not have a miRBase build ID specified")}
+    stop("this TxDb does not have a miRBase build ID specified")}
   ## now connect to mirbase
   require(mirbase.db) ## strictly required
 
@@ -711,8 +749,9 @@ setMethod("disjointExons", "TranscriptDb",
   ## connection
   mcon <- mirbase_dbconn()
   ## 1st lets get the organism abbreviation
-  sql <- paste0("SELECT organism FROM mirna_species WHERE genome_assembly='",
-                bld, "'")
+  sql <- paste0("SELECT organism FROM mirna_species WHERE genome_assembly",
+                " LIKE '", bld, "%'")
+
   organism <- dbGetQuery(mcon, sql)[[1]]
   ## now get data and make a GRanges from it
   sql <- paste0("SELECT * from mirna_chromosome_build AS csome INNER JOIN ",
@@ -740,7 +779,7 @@ setMethod("disjointExons", "TranscriptDb",
 setGeneric("microRNAs", function(x) standardGeneric("microRNAs"))
 
 ## Then set our method
-setMethod("microRNAs", "TranscriptDb", function(x){.microRNAs(x)} )
+setMethod("microRNAs", "TxDb", function(x){.microRNAs(x)} )
 
 
 
@@ -767,5 +806,17 @@ setMethod("microRNAs", "TranscriptDb", function(x){.microRNAs(x)} )
 
 setGeneric("tRNAs", function(x) standardGeneric("tRNAs"))
 
-setMethod("tRNAs", "TranscriptDb", function(x){.tRNAs(x)} )
+setMethod("tRNAs", "TxDb", function(x){.tRNAs(x)} )
+
+
+
+
+
+## Test code for new TXTYPE support (BC vs new code)
+## library(TxDb.Hsapiens.BioMart.ensembl.GRCh38);txdb2= TxDb.Hsapiens.BioMart.ensembl.GRCh38;transcripts(txdb2, columns='TXTYPE')
+## exons(txdb2, columns='TXTYPE')
+## And this one works now
+## library(TxDb.Hsapiens.UCSC.hg19.knownGene);txdb  = TxDb.Hsapiens.UCSC.hg19.knownGene;transcripts(txdb, columns='TXTYPE')
+## But this still fails (argh):
+## exons(txdb, columns='TXTYPE')
 
