@@ -33,6 +33,16 @@ makeTxDbPackageFromUCSC(version=version,
                         tablename="lincRNAsTranscripts",
                         miRBaseBuild="GRCh37")
 
+## Human HG38
+makeTxDbPackageFromUCSC(version=version,
+                        maintainer=maintainer,
+                        author=author,
+			destDir=TxDbOutDir,
+                        genome="hg38",
+                        tablename="knownGene")
+
+
+
 ## Mouse mm9
 makeTxDbPackageFromUCSC(version=version,
                         maintainer=maintainer,
@@ -58,7 +68,7 @@ makeTxDbPackageFromUCSC(version=version,
                         tablename="knownGene")
 
 
-## c elegans enseble trac
+## c elegans enseble track
 makeTxDbPackageFromUCSC(version=version,
                         maintainer=maintainer,
                         author=author,
@@ -73,13 +83,16 @@ makeTxDbPackageFromUCSC(version=version,
 			destDir=TxDbOutDir,
                         genome="dm3",
                         tablename="ensGene")
-                        
+
+
+## There is apparently a problem with this resource here:
+## It looks like the for the splicing is has missing fields...
 ## Arabidopsis biomaRt
 makeTxDbPackageFromBiomart(version=version,
                           maintainer=maintainer,
                           author=author,
 		 	  destDir=TxDbOutDir,
-                          biomart="plants_mart_21",
+                          biomart="plants_mart_25",
                           dataset="athaliana_eg_gene")
                                          
 
